package Bencher::Scenario::WordListModules;

our $DATE = '2016-01-08'; # DATE
our $VERSION = '0.02'; # VERSION

use 5.010001;
use strict;
use warnings;

our $scenario = {
    summary => 'Benchmark startup overhead of WordList::* modules',
    module_startup => 1,
    default_precision => 0.005,
    participants => [
        {module=>'WordList::EN::CountryNames'},
        {module=>'WordList::EN::CountryNames::SingleWord'},
        {module=>'WordList::EN::Enable'},
        {module=>'WordList::EN::SGB'},
        {module=>'WordList::ID::KBBI'},
        {module=>'WordList::Phrase::EN::Proverb::TWW'},
        {module=>'WordList::Phrase::ID::Proverb::KBBI'},
    ],
};

1;
# ABSTRACT: Benchmark startup overhead of WordList::* modules

__END__

=pod

=encoding UTF-8

=head1 NAME

Bencher::Scenario::WordListModules - Benchmark startup overhead of WordList::* modules

=head1 VERSION

This document describes version 0.02 of Bencher::Scenario::WordListModules (from Perl distribution Bencher-Scenario-WordListModules), released on 2016-01-08.

=head1 SYNOPSIS

To run benchmark with default option:

 % bencher -m WordListModules

For more options (dump scenario, list/include/exclude/add participants, list/include/exclude/add datasets, etc), see L<bencher> or run C<bencher --help>.

=head1 BENCHMARKED MODULES

L<WordList::EN::CountryNames> 0.02

L<WordList::EN::CountryNames::SingleWord> 0.02

L<WordList::EN::Enable> 0.01

L<WordList::EN::SGB> 0.01

L<WordList::ID::KBBI> 0.01

L<WordList::Phrase::EN::Proverb::TWW> 0.01

L<WordList::Phrase::ID::Proverb::KBBI> 0.01

=head1 BENCHMARK PARTICIPANTS

=over

=item * WordList::EN::CountryNames (perl_code)

L<WordList::EN::CountryNames>



=item * WordList::EN::CountryNames::SingleWord (perl_code)

L<WordList::EN::CountryNames::SingleWord>



=item * WordList::EN::Enable (perl_code)

L<WordList::EN::Enable>



=item * WordList::EN::SGB (perl_code)

L<WordList::EN::SGB>



=item * WordList::ID::KBBI (perl_code)

L<WordList::ID::KBBI>



=item * WordList::Phrase::EN::Proverb::TWW (perl_code)

L<WordList::Phrase::EN::Proverb::TWW>



=item * WordList::Phrase::ID::Proverb::KBBI (perl_code)

L<WordList::Phrase::ID::Proverb::KBBI>



=back

=head1 SAMPLE BENCHMARK RESULTS

Run on: perl: I<< v5.22.0 >>, CPU: I<< Intel(R) Core(TM) i5-2400 CPU @ 3.10GHz (4 cores) >>, OS: I<< GNU/Linux Debian version 8.0 >>, OS kernel: I<< Linux version 3.16.0-4-amd64 >>.

Benchmark with default option:

 +-----+----------------------------------------+--------+-------------------+---------+---------+
 | seq | name                                   | time   | mod_overhead_time | errors  | samples |
 +-----+----------------------------------------+--------+-------------------+---------+---------+
 | 2   | WordList::EN::CountryNames::SingleWord | 5.5ms  | 1.2ms             | 2.7e-05 | 46      |
 | 6   | WordList::Phrase::EN::Proverb::TWW     | 5.5ms  | 1.1ms             | 2.1e-05 | 20      |
 | 7   | WordList::Phrase::ID::Proverb::KBBI    | 5.4ms  | 1.1ms             | 2.6e-05 | 40      |
 | 5   | WordList::ID::KBBI                     | 5.38ms | 1.04ms            | 1.5e-05 | 20      |
 | 1   | WordList::EN::CountryNames             | 5.3ms  | 0.97ms            | 2.2e-05 | 20      |
 | 4   | WordList::EN::SGB                      | 5.3ms  | 0.92ms            | 1.7e-05 | 20      |
 | 3   | WordList::EN::Enable                   | 5.22ms | 0.882ms           | 1.4e-05 | 20      |
 | 0   | perl -e1 (baseline)                    | 4.3ms  | 0ms               | 1.8e-05 | 24      |
 +-----+----------------------------------------+--------+-------------------+---------+---------+

=head1 DESCRIPTION

Packaging a benchmark script as a Bencher scenario makes it convenient to include/exclude/add participants/datasets (either via CLI or Perl code), send the result to a central repository, among others . See L<Bencher> and L<bencher> (CLI) for more details.

=head1 HOMEPAGE

Please visit the project's homepage at L<https://metacpan.org/release/Bencher-Scenario-WordListModules>.

=head1 SOURCE

Source repository is at L<https://github.com/perlancar/perl-Bencher-Scenario-WordListModules>.

=head1 BUGS

Please report any bugs or feature requests on the bugtracker website L<https://rt.cpan.org/Public/Dist/Display.html?Name=Bencher-Scenario-WordListModules>

When submitting a bug or request, please include a test-file or a
patch to an existing test-file that illustrates the bug or desired
feature.

=head1 AUTHOR

perlancar <perlancar@cpan.org>

=head1 COPYRIGHT AND LICENSE

This software is copyright (c) 2016 by perlancar@cpan.org.

This is free software; you can redistribute it and/or modify it under
the same terms as the Perl 5 programming language system itself.

=cut
